@@ -114,6 +114,9 @@ elif board_id == ap_board.JETSON_NANO:
 elif board_id == ap_board.JETSON_NX:
     from adafruit_blinka.board.nvidia.jetson_nx import *
 
+elif board_id == ap_board.CLARA_AGX_XAVIER:
+    from adafruit_blinka.board.nvidia.clara_agx_xavier import *
+
 elif board_id == ap_board.CORAL_EDGE_TPU_DEV:
     from adafruit_blinka.board.coral_edge_tpu import *
 
@@ -162,6 +165,9 @@ elif board_id == ap_board.ROCK_PI_S:
 elif board_id == ap_board.UDOO_X86:
     from adafruit_blinka.board.udoo_x86ultra import *
 
+elif board_id == ap_board.STM32MP157C_DK2:
+    from adafruit_blinka.board.stm32.stm32mp157c_dk2 import *
+
 elif "sphinx" in sys.modules:
     pass
 
